@@ -5,11 +5,11 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 use File::HomeDir;
 use HTTP::Daemon;
-use HTTP::Daemon::patch::ipv6;
+use HTTP::Daemon::Patch::IPv6;
 use HTTP::Daemon::SSL;
 use HTTP::Daemon::UNIX;
 use HTTP::Date qw(time2str);
@@ -586,7 +586,7 @@ Gepok - PSGI server with built-in HTTPS support, Unix sockets, preforking
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
